import os
from PIL import Image
from panna import Depth2Image, DepthAnythingV2


model = Depth2Image()
model_depth = DepthAnythingV2()
os.makedirs("./test/test_image", exist_ok=True)
img = Image.open("./test/sample_image.png")

depth = model_depth.image2depth([img], return_tensor=True)
output = model.text2image(
    [img],
    depth_maps=depth,
    prompt=["a black cat"],
    negative_prompt=["bad, deformed, ugly, bad anatomy"],
    seed=42
)
model.export(output[0], "./test/test_image/test_depth2image.depth_anything.png")



import os
from PIL import Image
from panna import SVD

model = SVD()
img = Image.open("./test/sample_image.png")
os.makedirs("./test/test_video", exist_ok=True)

data = model.image2video([img], seed=42)
model.export(data[0], "./test/test_video/test_svd.motion_bucket_id=127.noise_aug_strength=0.02.mp4")

data = model.image2video([img], seed=42, motion_bucket_id=180)
model.export(data[0], "./test/test_video/test_svd.motion_bucket_id=180.noise_aug_strength=0.02.mp4")

data = model.image2video([img], seed=42, motion_bucket_id=180, noise_aug_strength=0.1)
model.export(data[0], "./test/test_video/test_svd.motion_bucket_id=180.noise_aug_strength=0.1.mp4")

data = model.image2video([img], seed=42, motion_bucket_id=180, noise_aug_strength=0.1, height=512, width=512)
model.export(data[0], "./test/test_video/test_svd.motion_bucket_id=180.noise_aug_strength=0.1.reshape.mp4")
